@@ -134,7 +134,8 @@ void rm_r (char *dirname)
       strcpy (zw, dirname);
       strcat (zw, "/");
       strcat (zw, dir_entry->d_name);
-      stat (zw, &buf);
+      /* NOTE: we don't follow symbolic links */
+      lstat (zw, &buf);
       if (S_ISDIR (buf.st_mode))
       {
         rm_r (zw);       /* Unterverzeichnisse loeschen */
@@ -327,11 +328,15 @@ void html_w_head (FILE *out, DB *tdb)
  
   path_index_cwd (cwd);
   db_title_read (tdb, cwd, zw2, sizeof (zw));
+
+  /* 
   if (strlen(zw2) == 0)
 	  {
 	  fprintf (stderr, "dhelp_parse: no title found for directory %s\n",
 			   cwd);
 	  }
+  */
+  
   fprintf (out, "<HTML>\n\n<HEAD>\n<TITLE>%s</TITLE>\n"
            "<LINK REV=made HREF=\"mailto:dhelp@packages.debian.org\">\n"
            "</HEAD>\n\n", zw2);
@@ -380,7 +385,7 @@ void html_w_tail (FILE *out)
                 "<INPUT TYPE=\"submit\" VALUE=\"%s\">\n"
                 "</FORM><BR>\n"
                 "[ <A HREF=\"/cgi-bin/info2www\">%s</A> | \n"
-                "<A HREF=\"/cgi-bin/man2html\">%s</A> | \n"
+                "<A HREF=\"/cgi-bin/man/man2html\">%s</A> | \n"
                 "<A HREF=\"../\">%s</A> ]\n</CENTER>\n",
                 search[i], info[i], man[i], other[i]);
   fprintf (out, "</BODY></HTML>\n");
